![falcondale](https://github.com/stafford-computing/falcondale-sdk/blob/main/assets/falcondale_sdk_black.png?raw=true)

Falcondale Software Development Kit (SDK) is an open source project aiming to ease the barrier for Data Scientists entering the field of Quantum Machine Learning.

## Documentation

Official documentation can be found here: https://falcondale.readthedocs.io/en/latest/

To check the roadmap of the project, have a look to: https://github.com/orgs/stafford-computing/projects/2

## How to contribute

Check out the [wiki](https://github.com/stafford-computing/falcondale-sdk/wiki/How-to-contribute) for the latest convention on how to contribute.

## Authors

* [Stafford Computing LLC](https://www.staffordcomputing.com/)

## License

This project is licensed under the terms of the MIT license.